@@ -109,8 +109,8 @@ class CameraModelTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = CameraModel
-        fields = ('model', 'mount', 'format', 'introduced',
-                  'body_type', 'negative_size')
+        fields = ('model', 'image', 'mount', 'format',
+                  'introduced', 'body_type', 'negative_size')
 
     @classmethod
     def render_model(cls, value, record):
@@ -132,6 +132,12 @@ class CameraModelTable(tables.Table):
             badge = format_html("")
         return mystr+badge
 
+    @classmethod
+    def render_image(cls, value):
+        if value:
+            icon = format_html('<img src="/static/svg/camera.svg" width="20" height="20" alt="This camera model has a photo" title="This camera model has a photo">')
+        return icon
+
     @classmethod
     def render_mount(cls, value):
         return format_html("<a href=\"{}\">{}</a>", reverse('mount-detail', args=[value.slug]), value)
@@ -288,7 +294,7 @@ class LensModelTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = LensModel
-        fields = ('model', 'mount', 'zoom', 'min_focal_length',
+        fields = ('model', 'image', 'mount', 'zoom', 'min_focal_length',
                   'max_aperture', 'autofocus', 'introduced')
 
     @classmethod
@@ -311,6 +317,12 @@ class LensModelTable(tables.Table):
             badge = format_html("")
         return mystr+badge
 
+    @classmethod
+    def render_image(cls, value):
+        if value:
+            icon = format_html('<img src="/static/svg/camera.svg" width="20" height="20" alt="This lens model has a photo" title="This lens model has a photo">')
+        return icon
+
     @classmethod
     def render_mount(cls, value):
         return format_html("<a href=\"{}\">{}</a>", reverse('mount-detail', args=[value.slug]), value)
